@@ -32,4 +32,5 @@ from .groundmodelsuite import GroundModelSuite
 from .parameter import Parameter
 from .parameterization import Parameterization
 
-from .target import Target
+from .modaltarget import ModalTarget, Target
+from .targetset import TargetSet
